@@ -92,17 +92,19 @@ types are: YAML (http://yaml.org/) and JSON (http://json.org/).
 		}
 
 		if reportOptions.filters != nil {
-			var filterPaths []*ytbx.Path
-			for _, pathString := range reportOptions.filters {
-				path, err := ytbx.ParsePathStringUnsafe(pathString)
-				if err != nil {
-					return wrap.Errorf(err, "failed to set path filter, because path %s cannot be parsed", pathString)
-				}
+			report = report.Filter(reportOptions.filters...)
+		}
 
-				filterPaths = append(filterPaths, &path)
-			}
+		if reportOptions.filterRegexps != nil {
+			report = report.FilterRegexp(reportOptions.filterRegexps...)
+		}
 
-			report = report.Filter(filterPaths...)
+		if reportOptions.excludes != nil {
+			report = report.Exclude(reportOptions.excludes...)
+		}
+
+		if reportOptions.excludeRegexps != nil {
+			report = report.ExcludeRegexp(reportOptions.excludeRegexps...)
 		}
 
 		return writeReport(cmd, report)
