@@ -360,15 +360,15 @@ func (report *HumanReport) writeStringDiff(output stringWriter, from string, to
 			for _, d := range diff {
 				switch d.Type {
 				case diffmatchpatch.DiffInsert:
-					bunt.Fprintf(&buf, green("%s", d.Text))
+					fmt.Fprint(&buf, green("%s", d.Text))
 					ins++
 
 				case diffmatchpatch.DiffDelete:
-					bunt.Fprintf(&buf, red("%s", d.Text))
+					fmt.Fprint(&buf, red("%s", d.Text))
 					del++
 
 				case diffmatchpatch.DiffEqual:
-					bunt.Fprintf(&buf, "DimGray{%s}", d.Text)
+					fmt.Fprint(&buf, dimgray("%s", d.Text))
 				}
 			}
 			fmt.Fprintln(&buf)
